/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.car;

import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * @author tzl
 * 2022/4/11 14:00
 */
@ApiModel("CarParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class CarParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 521351582969232371L;

    @ApiModelProperty(value = "车牌号码", example = "湘A99999", required = true)
    @NotEmpty(message = "车牌号码不能为空")
    @Pattern(regexp = RegEx.CARNUM, message = "车牌号码格式不正确")
    String carNum;

    @ApiModelProperty(value = "车辆类型", example = "1")
    String carType;

    @ApiModelProperty(value = "司机名称", example = "张三", required = true)
    @NotEmpty(message = "司机名称不能为空")
    String driverName;

    @ApiModelProperty(value = "司机电话", example = "17688888888", required = true)
    @NotEmpty(message = "司机电话不能为空")
    @Pattern(regexp = RegEx.MOBILE, message = "手机号码格式不正确")
    String driverMobile;

    @ApiModelProperty(value = "所属单位id", example = "1", required = true)
    @NotEmpty(message = "所属单位id不能为空")
    String orgId;

    @ApiModelProperty(value = "被访人id", example = "1", required = true)
    @NotEmpty(message = "被访人id不能为空")
    String intervieweeId;

    @ApiModelProperty(value = "来访原因", example = "视察", required = true)
    @NotEmpty(message = "来访原因不能为空")
    @Size(min = 1, max = 20, message = "来访原因超出范围")
    String reason;
}
