/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.post;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.auth.domain.post.Post;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 职位信息视图
 * @author LJ-2204
 * @date 2022/4/13
 */

@ApiModel("PostVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PostVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1011259844584399825L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "名称", example = "Java")
    String name;

    @ApiModelProperty(value = "描述", example = "描述")
    String describe;

    @ApiModelProperty(value = "创建时间", example = "创建时间")
    LocalDateTime createTime;

    @ApiModelProperty(value = "更新时间", example = "更新时间")
    LocalDateTime updateTime;

    @ApiModelProperty(value = "是否启用", example = "true")
    Boolean enable;

    public static PostVo transform(Post post) {
        return PostVo
            .builder()
            .id(post.getId())
            .name(post.getName())
            .describe(post.getDescribe())
            .enable(post.getEnable())
            .createTime(post.getCreateTime())
            .updateTime(post.getUpdateTime())
            .build();
    }

    public static List<PostVo> transforms(List<Post> posts) {
        return posts
            .stream()
            .map(post ->
                PostVo
                    .builder()
                    .id(post.getId())
                    .name(post.getName())
                    .describe(post.getDescribe())
                    .enable(post.getEnable())
                    .createTime(post.getCreateTime())
                    .updateTime(post.getUpdateTime())
                    .build()
            )
            .collect(Collectors.toList());
    }
}
